==> certmanager-model-v1-5.10.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1/OrderSpecBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OrderSpecBuilder extends io.fabric8.certmanager.api.model.acme.v1.OrderSpecFluentImpl<io.fabric8.certmanager.api.model.acme.v1.OrderSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.certmanager.api.model.acme.v1.OrderSpec,io.fabric8.certmanager.api.model.acme.v1.OrderSpecBuilder>{
  public OrderSpecBuilder() {
    this(false);
  }
  public OrderSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new OrderSpec(), validationEnabled);
  }
  public OrderSpecBuilder(io.fabric8.certmanager.api.model.acme.v1.OrderSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public OrderSpecBuilder(io.fabric8.certmanager.api.model.acme.v1.OrderSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OrderSpec(), validationEnabled);
  }
  public OrderSpecBuilder(io.fabric8.certmanager.api.model.acme.v1.OrderSpecFluent<?> fluent,io.fabric8.certmanager.api.model.acme.v1.OrderSpec instance) {
    this(fluent, instance, false);
  }
  public OrderSpecBuilder(io.fabric8.certmanager.api.model.acme.v1.OrderSpecFluent<?> fluent,io.fabric8.certmanager.api.model.acme.v1.OrderSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCommonName(instance.getCommonName()); 
    fluent.withDnsNames(instance.getDnsNames()); 
    fluent.withDuration(instance.getDuration()); 
    fluent.withIpAddresses(instance.getIpAddresses()); 
    fluent.withIssuerRef(instance.getIssuerRef()); 
    fluent.withRequest(instance.getRequest()); 
    this.validationEnabled = validationEnabled; 
  }
  public OrderSpecBuilder(io.fabric8.certmanager.api.model.acme.v1.OrderSpec instance) {
    this(instance,false);
  }
  public OrderSpecBuilder(io.fabric8.certmanager.api.model.acme.v1.OrderSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCommonName(instance.getCommonName()); 
    this.withDnsNames(instance.getDnsNames()); 
    this.withDuration(instance.getDuration()); 
    this.withIpAddresses(instance.getIpAddresses()); 
    this.withIssuerRef(instance.getIssuerRef()); 
    this.withRequest(instance.getRequest()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.certmanager.api.model.acme.v1.OrderSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.certmanager.api.model.acme.v1.OrderSpec build() {
    OrderSpec buildable = new OrderSpec(fluent.getCommonName(),fluent.getDnsNames(),fluent.getDuration(),fluent.getIpAddresses(),fluent.getIssuerRef(),fluent.getRequest());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OrderSpecBuilder that = (OrderSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> certmanager-model-v1-6.2.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1/OrderSpecBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OrderSpecBuilder extends OrderSpecFluentImpl<OrderSpecBuilder> implements VisitableBuilder<OrderSpec,OrderSpecBuilder>{
  public OrderSpecBuilder() {
    this(false);
  }
  public OrderSpecBuilder(Boolean validationEnabled) {
    this(new OrderSpec(), validationEnabled);
  }
  public OrderSpecBuilder(OrderSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public OrderSpecBuilder(OrderSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OrderSpec(), validationEnabled);
  }
  public OrderSpecBuilder(OrderSpecFluent<?> fluent,OrderSpec instance) {
    this(fluent, instance, false);
  }
  public OrderSpecBuilder(OrderSpecFluent<?> fluent,OrderSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCommonName(instance.getCommonName()); 
    fluent.withDnsNames(instance.getDnsNames()); 
    fluent.withDuration(instance.getDuration()); 
    fluent.withIpAddresses(instance.getIpAddresses()); 
    fluent.withIssuerRef(instance.getIssuerRef()); 
    fluent.withRequest(instance.getRequest()); 
    this.validationEnabled = validationEnabled; 
  }
  public OrderSpecBuilder(OrderSpec instance) {
    this(instance,false);
  }
  public OrderSpecBuilder(OrderSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withCommonName(instance.getCommonName()); 
    this.withDnsNames(instance.getDnsNames()); 
    this.withDuration(instance.getDuration()); 
    this.withIpAddresses(instance.getIpAddresses()); 
    this.withIssuerRef(instance.getIssuerRef()); 
    this.withRequest(instance.getRequest()); 
    this.validationEnabled = validationEnabled; 
  }
  OrderSpecFluent<?> fluent;
  Boolean validationEnabled;
  public OrderSpec build() {
    OrderSpec buildable = new OrderSpec(fluent.getCommonName(),fluent.getDnsNames(),fluent.getDuration(),fluent.getIpAddresses(),fluent.getIssuerRef(),fluent.getRequest());
    return buildable;
  }
  
}
